@@ -1,7 +1,4 @@
 package Test::Unit::Assertion::Exception;
-BEGIN {
-  $Test::Unit::Assertion::Exception::VERSION = '0.25_1325'; # added by dist-tools/SetVersion.pl
-}
 
 use strict;
 use base qw/Test::Unit::Assertion/;
@@ -15,13 +12,7 @@ my $deparser;
 sub new {
     my $class = shift;
     my $exception_class = shift;
-
-    my $prob;
-    $prob = "none given" unless defined $exception_class;
-    $prob = "$exception_class has no catch method"
-      unless UNIVERSAL::can($exception_class, "catch");
-    croak "$class\::new needs an exception class - $prob" if $prob;
-
+    croak "$class\::new needs an exception class" unless $exception_class;
     bless \$exception_class => $class;
 }
 
