@@ -67,7 +67,7 @@ sub create_suite {
     $set_up_func = \&{$set_up_candidates[0]} if @set_up_candidates;
 
     my @tear_down_candidates = grep /::tear_down$/, $st->functions;
-    $tear_down_func = \&{$set_up_candidates[0]} if @set_up_candidates;
+    $tear_down_func = \&{$tear_down_candidates[0]} if @tear_down_candidates;
 
     for my $test_method (grep /::test[^:]*$/, $st->functions) {
         my($method_name) = $test_method =~ /::(test[^:]*)/;
@@ -185,21 +185,15 @@ Please remember, Test::Unit::Procedural is intended to be a simple and
 convenient interface. If you need more functionality, take the
 object-oriented approach outlined in L<Test::Unit::TestCase>.
 
-
 =head1 AUTHOR
 
-Copyright (c) 2000, 2001 Christian Lemburg, E<lt>lemburg@acm.orgE<gt>.
+Copyright (c) 2000-2002, 2005 the PerlUnit Development Team
+(see L<Test::Unit> or the F<AUTHORS> file included in this
+distribution).
 
 All rights reserved. This program is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
-Thanks go to the other PerlUnit framework people: 
-Brian Ewins, Cayte Lindner, J.E. Fritz, Zhon Johansen, Matthew Astley,
-Adam Spiers, Piers Cawley.
-
-Thanks for patches and other contributions go to:
-David Esposito, Kevin Connor.
-
 =head1 SEE ALSO
 
 =over 4
