@@ -32,21 +32,21 @@ sub to_string {
 
 sub filter_method {
     my $self = shift;
-    my ($token, $method) = @_;
+    my ($token) = @_;
 
-    # Convert hash of arrayrefs from filter() into internally cached hash
-    # of hashrefs for faster lookup.
-    my $private = __PACKAGE__ . '_filter';
-    if (! exists $self->{$private}{$token}) {
-        my @methods = @{ $self->filter->{$token} || [] };
-        $self->{$private}{$token} = { map { $_ => 1 } @methods };
+    my $filtered = $self->filter->{$token};
+    return unless $filtered;
+
+    if (ref $filtered eq 'ARRAY') {
+        return grep $self->name eq $_, @$filtered;
+    }
+    elsif (ref $filtered eq 'CODE') {
+        return $filtered->($self->name);
+    }
+    else {
+        die "Didn't understand filtering definition for token $token in ",
+            ref($self), "\n";
     }
-
-    my $filtered = $self->{$private}{$token}{$method};
-    debug("filter $method by token $token? ",
-          $filtered ? 'yes' : 'no',
-	  "\n");
-    return $filtered;
 }
 
 my %filter = ();
@@ -119,14 +119,13 @@ really needed, but rather serves as documentation of the interface.
 
 =head1 AUTHOR
 
-Copyright (c) 2000 Christian Lemburg, E<lt>lemburg@acm.orgE<gt>.
+Copyright (c) 2000-2002, 2005 the PerlUnit Development Team
+(see L<Test::Unit> or the F<AUTHORS> file included in this
+distribution).
 
 All rights reserved. This program is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
-Thanks go to the other PerlUnit framework people: 
-Brian Ewins, Cayte Lindner, J.E. Fritz, Zhon Johansen.
-
 =head1 SEE ALSO
 
 =over 4
