@@ -63,6 +63,8 @@ sub test_assert {
     $self->assert($coderef, 'a', 'a');
     $self->assert([]);
     $self->assert([ 'foo', 7 ]);
+
+    my $qr_string = "" . qr/foo/; # for use in tests below
     $self->check_failures(
         'Boolean assertion failed' => [ __LINE__, sub { shift->assert(undef) } ],
         'Boolean assertion failed' => [ __LINE__, sub { shift->assert(0)   } ],
@@ -70,7 +72,7 @@ sub test_assert {
 
         'bang'  => [ __LINE__, sub { shift->assert(0, 'bang')              } ],
         'bang'  => [ __LINE__, sub { shift->assert('', 'bang')             } ],
-        "'qux' did not match /(?-xism:foo)/"
+        "'qux' did not match /$qr_string/"
                 => [ __LINE__, sub { shift->assert(qr/foo/, 'qux')         } ],
         'bang'  => [ __LINE__, sub { shift->assert(qr/foo/, 'qux', 'bang') } ],
         'a ne b'=> [ __LINE__, sub { shift->assert($coderef, 'a', 'b')     } ],
@@ -243,18 +245,21 @@ sub test_ok_equals {
 sub test_ok_not_equals {
     my $self = shift;
     my $adder = sub { 2+2 };
+
+    my $qr_string = "" . qr/x/; # To interpolate below in @checks
     my @checks = (
         # interface is ok(GOT, EXPECTED);
-        q{expected 1, got 0}                => [ 0,      1       ], 
-        q{expected 0, got 1}                => [ 1,      0       ], 
-        q{expected 3, got 2}                => [ 2,      3       ], 
-        q{expected -57.001, got -57}        => [ -57,    -57.001 ], 
-        q{expected 'bar', got 'foo'}        => [ 'foo',  'bar'   ], 
-        q{expected '', got 'foo'}           => [ 'foo',  ''      ], 
-        q{expected 'foo', got ''}           => [ '',     'foo'   ], 
-        q{expected 5, got 4}                => [ $adder, 5       ], 
-        q{'foo' did not match /(?-xism:x)/} => [ 'foo',  qr/x/   ], 
+        q{expected 1, got 0}                  => [ 0,      1       ],
+        q{expected 0, got 1}                  => [ 1,      0       ],
+        q{expected 3, got 2}                  => [ 2,      3       ],
+        q{expected -57.001, got -57}          => [ -57,    -57.001 ],
+        q{expected 'bar', got 'foo'}          => [ 'foo',  'bar'   ],
+        q{expected '', got 'foo'}             => [ 'foo',  ''      ],
+        q{expected 'foo', got ''}             => [ '',     'foo'   ],
+        q{expected 5, got 4}                  => [ $adder, 5       ],
+        qq{'foo' did not match /$qr_string/}  => [ 'foo',  qr/x/   ],
     );
+
     my @tests = ();
     while (@checks) {
         my $expected = shift @checks;
